@@ -7,7 +7,7 @@ use v5.24;
 use strict;
 use warnings;
 
-our $VERSION = '1.1.0'; # VERSION
+our $VERSION = '1.1.1'; # VERSION
 
 use namespace::autoclean;
 
@@ -176,7 +176,10 @@ has exclude_from_basic => (
     lazy    => 1,
     default => sub {
         my $pl = $_[0]->payload;
-        $pl->{exclude_from_basic};
+        my $exclude = $pl->{exclude_from_basic};
+        $exclude ?
+            ref $exclude ? $exclude : [ $exclude ]
+            : []
     },
 );
 
@@ -373,7 +376,7 @@ Dist::Zilla::PluginBundle::PERLSRVDE - The plugin bundle we use at Perl-Services
 
 =head1 VERSION
 
-version 1.1.0
+version 1.1.1
 
 =head1 SYNOPSIS
 
